#!/usr/bin/env bash
set -x

# Sanity check for input
if [ "$#" -lt 1 ]; then
	echo "Usage: deploy-scep.sh <restartpolicy>"
	exit 1
fi

restartpolicy=$1

CURDIR=${PWD}
KEYDIR=${CURDIR}/etc/banyan-ca
DKEYDIR=/root/depot
ROLENAME=end-client-rolename
CHALLENGE=replace-me
CRTVALID=365
SCEP_REPO=pub.banyanops.com/scepserver:latest

if [ -f "${KEYDIR}"/ca.key ]; then
	sudo /bin/rm -f "${KEYDIR}"/ca.key
fi
sudo docker pull "${SCEP_REPO}"
sudo docker run --rm -v ${KEYDIR}:${DKEYDIR} ${SCEP_REPO} ca -cfssl

sudo docker run -d -p 127.0.0.1:8080:8080 -v ${KEYDIR}:${DKEYDIR} --restart=${restartpolicy} --name scepserver --label com.banyanops.app="banyan-platform" --label com.banyanops.servicename="shieldsvc" ${SCEP_REPO} -dnsnames ${ROLENAME} -challenge ${CHALLENGE} -crtvalid ${CRTVALID}
